@@ -15,9 +15,9 @@ import com.unciv.logic.civilization.managers.ReligionState
 import com.unciv.logic.map.mapunit.MapUnit
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.ruleset.unique.UniqueType
-import com.unciv.ui.worldscreen.unit.actions.UnitActions
-import com.unciv.ui.worldscreen.unit.actions.UnitActionsPillage
-import com.unciv.ui.worldscreen.unit.actions.UnitActionsUpgrade
+import com.unciv.ui.screens.worldscreen.unit.actions.UnitActions
+import com.unciv.ui.screens.worldscreen.unit.actions.UnitActionsPillage
+import com.unciv.ui.screens.worldscreen.unit.actions.UnitActionsUpgrade
 
 object UnitAutomation {
 
@@ -262,7 +262,8 @@ object UnitAutomation {
         if (unit.hasUnique(UniqueType.PreventSpreadingReligion) || unit.canDoReligiousAction(Constants.removeHeresy))
             return SpecificUnitAutomation.automateInquisitor(unit)
 
-        if (unit.hasUnique(UniqueType.ConstructImprovementConsumingUnit))
+        if (unit.hasUnique(UniqueType.ConstructImprovementConsumingUnit)
+                || unit.hasUnique(UniqueType.ConstructImprovementInstantly))
         // catch great prophet for civs who can't found/enhance/spread religion
             return SpecificUnitAutomation.automateImprovementPlacer(unit) // includes great people plus moddable units
 
