@@ -125,7 +125,8 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
         state: StateForConditionals
     ): Boolean {
 
-        if (condition.type!!.targetTypes.contains(UniqueTarget.TriggerCondition))
+        val nonConditionalConditionTypes = setOf(UniqueTarget.TriggerCondition, UniqueTarget.UnitTriggerCondition, UniqueTarget.UnitActionModifier)
+        if (condition.type!!.targetTypes.any { it in nonConditionalConditionTypes })
             return true // not a filtering condition
 
         fun ruleset() = state.civInfo!!.gameInfo.ruleset
@@ -146,7 +147,6 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
         return when (condition.type) {
             // These are 'what to do' and not 'when to do' conditionals
             UniqueType.ConditionalTimedUnique -> true
-            UniqueType.ConditionalConsumeUnit -> true
 
             UniqueType.ConditionalBeforeTurns -> state.civInfo != null && state.civInfo.gameInfo.turns < condition.params[0].toInt()
             UniqueType.ConditionalAfterTurns -> state.civInfo != null && state.civInfo.gameInfo.turns >= condition.params[0].toInt()
@@ -193,6 +193,14 @@ class Unique(val text: String, val sourceObjectType: UniqueTarget? = null, val s
                 state.civInfo != null && state.civInfo.religionManager.religionState == ReligionState.None
             UniqueType.ConditionalAfterPantheon ->
                 state.civInfo != null && state.civInfo.religionManager.religionState != ReligionState.None
+            UniqueType.ConditionalBeforeReligion ->
+                state.civInfo != null && state.civInfo.religionManager.religionState < ReligionState.Religion
+            UniqueType.ConditionalAfterReligion ->
+                state.civInfo != null && state.civInfo.religionManager.religionState >= ReligionState.Religion
+            UniqueType.ConditionalBeforeEnhancingReligion ->
+                state.civInfo != null && state.civInfo.religionManager.religionState < ReligionState.EnhancedReligion
+            UniqueType.ConditionalAfterEnhancingReligion ->
+                state.civInfo != null && state.civInfo.religionManager.religionState >= ReligionState.EnhancedReligion
             UniqueType.ConditionalBuildingBuilt ->
                 state.civInfo != null && state.civInfo.cities.any { it.cityConstructions.containsBuildingOrEquivalent(condition.params[0]) }
 
