@@ -18,16 +18,17 @@ import com.unciv.models.UncivSound
 import com.unciv.models.UnitAction
 import com.unciv.models.UnitActionType
 import com.unciv.models.ruleset.unique.StateForConditionals
+import com.unciv.models.ruleset.unique.Unique
+import com.unciv.models.ruleset.unique.UniqueTarget
 import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
+import com.unciv.models.translations.removeConditionals
 import com.unciv.models.translations.tr
-import com.unciv.ui.screens.pickerscreens.ImprovementPickerScreen
-import com.unciv.ui.screens.pickerscreens.PromotionPickerScreen
+import com.unciv.ui.components.Fonts
 import com.unciv.ui.popups.ConfirmPopup
 import com.unciv.ui.popups.hasOpenPopups
-import com.unciv.ui.components.Fonts
-import com.unciv.ui.screens.worldscreen.WorldScreen
-import com.unciv.ui.screens.worldscreen.unit.UnitTable
+import com.unciv.ui.screens.pickerscreens.ImprovementPickerScreen
+import com.unciv.ui.screens.pickerscreens.PromotionPickerScreen
 
 object UnitActions {
 
@@ -52,8 +53,13 @@ object UnitActions {
 
         addPromoteAction(unit, actionList)
         UnitActionsUpgrade.addUnitUpgradeAction(unit, actionList)
-        addTransformAction(unit, actionList)
         UnitActionsPillage.addPillageAction(unit, actionList)
+        addExplorationActions(unit, actionList)
+        addWaitAction(unit, actionList)
+        addToggleActionsAction(unit, actionList)
+
+        // Determined by unit uniques
+        addTransformAction(unit, actionList)
         addParadropAction(unit, actionList)
         addAirSweepAction(unit, actionList)
         addSetupAction(unit, actionList)
@@ -66,15 +72,10 @@ object UnitActions {
         UnitActionsReligion.addEnhanceReligionAction(unit, actionList)
         actionList += getImprovementConstructionActions(unit, tile)
         UnitActionsReligion.addActionsWithLimitedUses(unit, actionList, tile)
-        addExplorationActions(unit, actionList)
         addAutomateBuildingImprovementsAction(unit, actionList)
         addTriggerUniqueActions(unit, actionList)
         addAddInCapitalAction(unit, actionList, tile)
 
-        addWaitAction(unit, actionList)
-
-        addToggleActionsAction(unit, actionList)
-
         return actionList
     }
 
@@ -455,7 +456,8 @@ object UnitActions {
 
     fun getImprovementConstructionActions(unit: MapUnit, tile: Tile): ArrayList<UnitAction> {
         val finalActions = ArrayList<UnitAction>()
-        val uniquesToCheck = unit.getMatchingUniques(UniqueType.ConstructImprovementConsumingUnit)
+        val uniquesToCheck = unit.getMatchingUniques(UniqueType.ConstructImprovementConsumingUnit) +
+                unit.getMatchingUniques(UniqueType.ConstructImprovementInstantly)
         val civResources = unit.civ.getCivResourcesByName()
 
         for (unique in uniquesToCheck) {
@@ -468,15 +470,21 @@ object UnitActions {
                         (civResources[unique.params[1]] ?: 0) < unique.params[0].toInt()
             }
 
+            val sideEffectsString = getSideEffectString(unique)
+            val title = if (sideEffectsString.isEmpty()) "Create [$improvementName]"
+            else "{Create [$improvementName]} {$sideEffectsString}"
+
             finalActions += UnitAction(UnitActionType.Create,
-                title = "Create [$improvementName]",
+                title = title,
                 action = {
                     val unitTile = unit.getTile()
                     unitTile.improvementFunctions.removeCreatesOneImprovementMarker()
                     unitTile.changeImprovement(improvementName)
                     unitTile.stopWorkingOnImprovement()
                     improvement.handleImprovementCompletion(unit)
-                    unit.consume()
+
+                    if (unique.type == UniqueType.ConstructImprovementConsumingUnit) unit.consume()
+                    else activateSideEffects(unit, unique)
                 }.takeIf {
                     resourcesAvailable
                     && unit.currentMovement > 0f
@@ -638,11 +646,14 @@ object UnitActions {
     }
 
     private fun addTriggerUniqueActions(unit: MapUnit, actionList: ArrayList<UnitAction>){
+        val triggerableTypes = setOf(UniqueTarget.Triggerable, UniqueTarget.UnitTriggerable)
         for (unique in unit.getUniques()) {
-            if (!unique.conditionals.any { it.type == UniqueType.ConditionalConsumeUnit }) continue
-            val unitAction = UnitAction(type = UnitActionType.TriggerUnique, unique.text){
-                UniqueTriggerActivation.triggerCivwideUnique(unique, unit.civ)
-                unit.consume()
+            if (unique.conditionals.none { it.type?.targetTypes?.contains(UniqueTarget.UnitActionModifier) == true }) continue
+            if (unique.type?.targetTypes?.any { it in triggerableTypes }!=true) continue
+
+            val unitAction = UnitAction(type = UnitActionType.TriggerUnique, unique.text.removeConditionals()){
+                UniqueTriggerActivation.triggerUnitwideUnique(unique, unit)
+                activateSideEffects(unit, unique)
             }
             actionList += unitAction
         }
@@ -668,4 +679,23 @@ object UnitActions {
             }
         )
     }
+
+    fun activateSideEffects(unit: MapUnit, actionUnique: Unique){
+        var conditionalsWithNoSideEffect = 0
+        for (conditional in actionUnique.conditionals){
+            when (conditional.type){
+                UniqueType.UnitActionConsumeUnit -> unit.consume()
+                else -> conditionalsWithNoSideEffect++
+            }
+        }
+        if (conditionalsWithNoSideEffect == actionUnique.conditionals.size)
+            unit.useMovementPoints(1f)
+    }
+
+    fun getSideEffectString(actionUnique: Unique): String {
+        val effects = ArrayList<String>()
+        if (actionUnique.conditionals.any { it.type == UniqueType.UnitActionConsumeUnit }) effects += Fonts.death.toString()
+        return if (effects.isEmpty()) ""
+        else "(${effects.joinToString { it.tr() }})"
+    }
 }
